==> vacuum-1.1.0.tar.xz: vacuum-1.1.0/src/translations/de/clientinfo.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="de" sourcelanguage="en">
<context>
    <name>ClientInfo</name>
    <message>
        <source>Software: %1 %2</source>
        <translation>Software: %1 %2</translation>
    </message>
    <message>
        <source>Entity time: %1</source>
        <translation>Laufzeit: %1</translation>
    </message>
    <message>
        <source>Software information</source>
        <translation>Software Informationen</translation>
    </message>
    <message>
        <source>Software</source>
        <translation>Software</translation>
    </message>
    <message>
        <source>Software Version</source>
        <translation>Software Version</translation>
    </message>
    <message>
        <source>OS</source>
        <translation>ОS</translation>
    </message>
    <message>
        <source>OS Version</source>
        <translation>OS Version</translation>
    </message>
    <message>
        <source>Client Information</source>
        <translation>Client Informationen</translation>
    </message>
    <message>
        <source>Allows to send and receive information about the version of the application, the local time and the last activity of contact</source>
        <translation>Ermöglicht das Senden und Empfangen von Informationen über die Version der Anwendung, der Lokalzeit und der letzten Aktivität des Kontakts</translation>
    </message>
    <message>
        <source>Supports the exchanging of the information about the application version</source>
        <translation>Unterstütz den Austausch von Informationen über die Version der Anwendung</translation>
    </message>
    <message>
        <source>Last Activity</source>
        <translation>Letzte Aktivität</translation>
    </message>
    <message>
        <source>Supports the exchanging of the information about the user last activity</source>
        <translation>Unterstütz den Austausch von Informationen über die letzte Aktivität des Benutzers</translation>
    </message>
    <message>
        <source>Entity Time</source>
        <translation>Laufzeit</translation>
    </message>
    <message>
        <source>Supports the exchanging of the information about the user local time</source>
        <translation>Unterstützt dan Austausch von Informationen über die Lokalzeit des Benutzers</translation>
    </message>
    <message>
        <source>Service Uptime</source>
        <translation></translation>
    </message>
    <message>
        <source>Idle Time</source>
        <translation></translation>
    </message>
    <message>
        <source>Share information about OS version</source>
        <translation></translation>
    </message>
    <message>
        <source>XMPP Ping</source>
        <translation></translation>
    </message>
    <message>
        <source>Supports the exchanging of the application-level pings over XML streams</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>ClientInfoDialog</name>
    <message>
        <source>Client info - %1</source>
        <translation>Client Info - %1</translation>
    </message>
    <message>
        <source>Name:</source>
        <translation>Name:</translation>
    </message>
    <message>
        <source>Version:</source>
        <translation>Version:</translation>
    </message>
    <message>
        <source>OS:</source>
        <translation>OS:</translation>
    </message>
    <message>
        <source>Error:</source>
        <translation>Fehler:</translation>
    </message>
    <message>
        <source>Status:</source>
        <translation>Status:</translation>
    </message>
    <message>
        <source>Time:</source>
        <translation>Zeit:</translation>
    </message>
    <message>
        <source>Delta:</source>
        <translation>Delta:</translation>
    </message>
    <message>
        <source>Ping, msec:</source>
        <translation>Ping, msek:</translation>
    </message>
    <message>
        <source>Software Version</source>
        <translation></translation>
    </message>
    <message>
        <source>Service Uptime</source>
        <translation></translation>
    </message>
    <message>
        <source>Last Activity</source>
        <translation></translation>
    </message>
    <message>
        <source>Idle Time</source>
        <translation></translation>
    </message>
    <message>
        <source>Uptime:</source>
        <translation></translation>
    </message>
    <message>
        <source>Inactive:</source>
        <translation></translation>
    </message>
    <message>
        <source>Idle:</source>
        <translation></translation>
    </message>
    <message>
        <source>Entity Time</source>
        <translation></translation>
    </message>
    <message>
        <source>Not available</source>
        <translation></translation>
    </message>
    <message>
        <source>%1y</source>
        <comment>years</comment>
        <translation></translation>
    </message>
    <message>
        <source>%1d</source>
        <comment>days</comment>
        <translation></translation>
    </message>
    <message>
        <source>%1h</source>
        <comment>hours</comment>
        <translation></translation>
    </message>
    <message>
        <source>%1m</source>
        <comment>minutes</comment>
        <translation></translation>
    </message>
    <message>
        <source>%1s</source>
        <comment>seconds</comment>
        <translation></translation>
    </message>
    <message>
        <source>Waiting response...</source>
        <translation></translation>
    </message>
</context>
</TS>

==> vacuum-1.2.4.tar.xz: vacuum-1.2.4/src/translations/de/clientinfo.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="de" sourcelanguage="en">
<context>
    <name>ClientInfo</name>
    <message>
        <source>Software: %1 %2</source>
        <translation>Software: %1 %2</translation>
    </message>
    <message>
        <source>Entity time: %1</source>
        <translation>Laufzeit: %1</translation>
    </message>
    <message>
        <source>Software information</source>
        <translation>Software Informationen</translation>
    </message>
    <message>
        <source>Software</source>
        <translation>Software</translation>
    </message>
    <message>
        <source>Software Version</source>
        <translation>Software Version</translation>
    </message>
    <message>
        <source>OS</source>
        <translation>OS</translation>
    </message>
    <message>
        <source>OS Version</source>
        <translation>OS Version</translation>
    </message>
    <message>
        <source>Client Information</source>
        <translation>Client Informationen</translation>
    </message>
    <message>
        <source>Allows to send and receive information about the version of the application, the local time and the last activity of contact</source>
        <translation>Ermöglicht das Senden und Empfangen von Informationen über die Version der Anwendung, der Lokalzeit und der letzten Aktivität des Kontakts</translation>
    </message>
    <message>
        <source>Supports the exchanging of the information about the application version</source>
        <translation>Unterstützt den Austausch von Informationen über die Anwendungsversion</translation>
    </message>
    <message>
        <source>Last Activity</source>
        <translation>Letzte Aktivität</translation>
    </message>
    <message>
        <source>Supports the exchanging of the information about the user last activity</source>
        <translation>Unterstützt den Austausch von Informationen über die letzte Aktivität des Benutzers</translation>
    </message>
    <message>
        <source>Entity Time</source>
        <translation>Laufzeit</translation>
    </message>
    <message>
        <source>Supports the exchanging of the information about the user local time</source>
        <translation>Unterstützt den Austausch von Informationen über die Lokalzeit des Benutzers</translation>
    </message>
    <message>
        <source>Service Uptime</source>
        <translation>Service Uptime</translation>
    </message>
    <message>
        <source>Idle Time</source>
        <translation>Inaktiv seit</translation>
    </message>
    <message>
        <source>Share information about OS version</source>
        <translation>Informationen über OS Version freigeben</translation>
    </message>
    <message>
        <source>XMPP Ping</source>
        <translation>XMPP Ping</translation>
    </message>
    <message>
        <source>Supports the exchanging of the application-level pings over XML streams</source>
        <translation>Erlaubt den Austausch von Anwendungs Pings über XML Datenströme</translation>
    </message>
</context>
<context>
    <name>ClientInfoDialog</name>
    <message>
        <source>Client info - %1</source>
        <translation>Client Info - %1</translation>
    </message>
    <message>
        <source>Name:</source>
        <translation>Name:</translation>
    </message>
    <message>
        <source>Version:</source>
        <translation>Version:</translation>
    </message>
    <message>
        <source>OS:</source>
        <translation>OS:</translation>
    </message>
    <message>
        <source>Error:</source>
        <translation>Fehler:</translation>
    </message>
    <message>
        <source>Status:</source>
        <translation>Status:</translation>
    </message>
    <message>
        <source>Time:</source>
        <translation>Zeit:</translation>
    </message>
    <message>
        <source>Delta:</source>
        <translation>Delta:</translation>
    </message>
    <message>
        <source>Ping, msec:</source>
        <translation>Ping, msek:</translation>
    </message>
    <message>
        <source>Software Version</source>
        <translation>Software Version</translation>
    </message>
    <message>
        <source>Service Uptime</source>
        <translation>Service Uptime</translation>
    </message>
    <message>
        <source>Last Activity</source>
        <translation>Letzte Aktivität</translation>
    </message>
    <message>
        <source>Idle Time</source>
        <translation>Inaktiv seit</translation>
    </message>
    <message>
        <source>Uptime:</source>
        <translation>Uptime:</translation>
    </message>
    <message>
        <source>Inactive:</source>
        <translation>Inaktiv:</translation>
    </message>
    <message>
        <source>Idle:</source>
        <translation>Idle:</translation>
    </message>
    <message>
        <source>Entity Time</source>
        <translation>Laufzeit</translation>
    </message>
    <message>
        <source>Not available</source>
        <translation>Nicht verfügbar</translation>
    </message>
    <message>
        <source>%1y</source>
        <comment>years</comment>
        <translation>%1y</translation>
    </message>
    <message>
        <source>%1d</source>
        <comment>days</comment>
        <translation>%1d</translation>
    </message>
    <message>
        <source>%1h</source>
        <comment>hours</comment>
        <translation>%1h</translation>
    </message>
    <message>
        <source>%1m</source>
        <comment>minutes</comment>
        <translation>%1m</translation>
    </message>
    <message>
        <source>%1s</source>
        <comment>seconds</comment>
        <translation>%1s</translation>
    </message>
    <message>
        <source>Waiting response...</source>
        <translation>Erwarte Antwort ...</translation>
    </message>
</context>
</TS>
